import { Box, LinearProgress, TextField, Typography } from "@mui/material";
import { useState } from "react";
import { useNotification } from "../../../contexts/NotificationContext";
import { HeaderLogo } from "../../Generic/HeaderLogo";

export const SqlInjection = () => {
  // contexts
  const { openNotification } = useNotification();

  // states
  const [passwordValueRaw, setPasswordValueRaw] = useState<string>("");
  const [rePasswordValueRaw, setRePasswordValueRaw] = useState<string>("");
  const [passwordErrorMsg, setPasswordErrorMsg] = useState<string>("");
  // password strength meter
  const [passwordStrength, setPasswordStrength] = useState(0);
  const [passwordStrengthColor, setPasswordStrengthColor] = useState<"primary" | "error" | "warning" | "success">(
    "primary",
  );
  const [PasswordStrengthInfo, setPasswordStrengthInfo] = useState("Enter a password");

  let newPasswordStrengthInfo = "Enter a password";

  const calculatePasswordStrength = (passwordValueRaw: string) => {
    let strengthPoints = 0;

    // logic for calculating password strength
    if (passwordValueRaw.length >= 8 && passwordValueRaw.length <= 128) {
      strengthPoints += 20;
    }
    if (passwordValueRaw.match(/[a-z]/g)) {
      strengthPoints += 20;
    }
    if (passwordValueRaw.match(/[A-Z]/g)) {
      strengthPoints += 20;
    }
    if (passwordValueRaw.match(/[0-9]/g)) {
      strengthPoints += 20;
    }
    if (passwordValueRaw.match(/[^a-zA-Z\d]/g)) {
      strengthPoints += 20;
    }

    // calculate strengthPoints as a percentage
    strengthPoints = Math.min(strengthPoints, 100);

    // logic for changing color of progress bar
    if (strengthPoints === 0) {
      setPasswordStrengthColor("primary");
      newPasswordStrengthInfo = "Enter a password";
    } else if (strengthPoints <= 20) {
      setPasswordStrengthColor("error");
      newPasswordStrengthInfo = "Password strength is weak";
    } else if (strengthPoints <= 40) {
      setPasswordStrengthColor("warning");
      newPasswordStrengthInfo = "Password strength is decent";
    } else if (strengthPoints <= 60) {
      setPasswordStrengthColor("warning");
      newPasswordStrengthInfo = "Password strength is decent";
    } else if (strengthPoints <= 80) {
      setPasswordStrengthColor("success");
      newPasswordStrengthInfo = "Password strength is good";
    } else if (strengthPoints <= 100) {
      setPasswordStrengthColor("success");
      newPasswordStrengthInfo = "Password strength is strong";
    }

    // update state
    setPasswordStrength(strengthPoints);
    setPasswordStrengthInfo(newPasswordStrengthInfo);
  };

  return (
    <Box
      sx={{
        display: "flex",
        justifyContent: "center",
        alignItems: "center",
        height: "100vh",
      }}
    >
      <Box
        sx={{
          border: "solid 1px grey",
          borderRadius: 2,
          p: 4,
          minWidth: "300px",
          maxWidth: "400px",
        }}
      >
        <Box
          alignItems="center"
          display="flex"
          flexDirection="row"
          sx={{
            mb: 2,
          }}
        >
          <HeaderLogo />
          <Typography
            sx={{
              color: "grey",
            }}
            variant="h6"
          >
            &nbsp;Login
          </Typography>
        </Box>
        <Box
          sx={{
            display: "flex",
            flexDirection: "column",
          }}
        >
          <TextField
            error={Boolean(passwordErrorMsg)}
            fullWidth
            helperText={Boolean(passwordErrorMsg) ? passwordErrorMsg : ""}
            id="email"
            label="Email"
            size="small"
            type="email"
            // value={value}
            sx={{ mb: 2 }}
            variant="outlined"
          />
          <TextField
            error={Boolean(passwordErrorMsg)}
            fullWidth
            helperText={Boolean(passwordErrorMsg) ? passwordErrorMsg : ""}
            id="password"
            label="Password"
            size="small"
            type="password"
            // value={value}
            sx={{ mb: 2 }}
            variant="outlined"
          />
          <TextField
            error={Boolean(passwordErrorMsg)}
            fullWidth
            helperText={Boolean(passwordErrorMsg) ? passwordErrorMsg : ""}
            id="re-password"
            label="Re-enter password"
            size="small"
            type="password"
            // value={value}
            sx={{ mb: 2 }}
            variant="outlined"
          />
          <LinearProgress
            color={passwordStrengthColor}
            value={passwordStrength}
            variant="determinate"
          />
        </Box>
      </Box>
    </Box>
  );
};
